@@ -450,9 +450,9 @@ impl Kubectl {
 pub(crate) fn extract_cluster_token(secret: &Secret) -> Option<Cow<'_, str>> {
     secret
         .data
-        .get("cluster-token")
-        .map(|bytes| bytes.0.as_slice())
-        .map(String::from_utf8_lossy)
+        .as_ref()
+        .and_then(|data| data.get("cluster-token"))
+        .map(|bytes| String::from_utf8_lossy(&bytes.0))
 }
 
 pub(crate) fn get_current_cluster_name() -> Option<v0::ClusterName> {
