@@ -692,6 +692,8 @@ impl Cli {
                 aws,
                 azure,
             } => {
+                aws.validate()?;
+                azure.validate()?;
                 let (kubectls, register_cluster) = if non_interactive {
                     statehub
                         .non_interactive_register_cluster_helper(
@@ -762,6 +764,8 @@ impl Cli {
                 //     )
                 // })?;
                 // let kubectl = k8s::Kubectl::with_context_or_current(None)?;
+                aws.validate()?;
+                azure.validate()?;
                 statehub
                     .update_cluster(name, context, namespace, aws, azure)
                     .await
@@ -1043,7 +1047,7 @@ impl StateHub {
         let kubectls = k8s::Kubectl::with_names_and_contexts(names, contexts)?;
 
         for kubectl in kubectls {
-            self.inform(format_args!(
+            self.inform2(format_args!(
                 "Updating cluster with K8s context {} with {:?}",
                 kubectl.cluster_name(),
                 azure
@@ -1067,7 +1071,7 @@ impl StateHub {
 
     async fn diagnose_cluster(&self, kubectls: Vec<k8s::Kubectl>) -> anyhow::Result<()> {
         for kubectl in kubectls {
-            self.inform(format_args!(
+            self.inform2(format_args!(
                 "Running diagnostics on cluster '{}' (K8s context '{}')",
                 kubectl.cluster_name(),
                 kubectl.context(),
@@ -1076,9 +1080,9 @@ impl StateHub {
             futures::pin_mut!(check_cluster);
             while let Some(item) = check_cluster.next().await {
                 match item {
-                    Ok(text) => self.inform(text)?,
+                    Ok(text) => self.inform2(text)?,
                     Err(text) => {
-                        self.inform(text)?;
+                        self.inform2(text)?;
                         break;
                     }
                 }
@@ -1114,7 +1118,7 @@ impl StateHub {
             AddLocation::FromLocation(location) => vec![location],
             AddLocation::FromCluster(cluster) => {
                 let locations = self.api.get_cluster(&cluster).await?.all_locations();
-                self.inform(format_args!(
+                self.inform2(format_args!(
                     "Cluster {} available in {}",
                     cluster,
                     locations.iter().map(ToString::to_string).join(" and ")
@@ -1128,12 +1132,12 @@ impl StateHub {
         for location in locations {
             let state = self.api.get_state(&state).await?;
             if state.is_available_in(&location) {
-                self.inform(format_args!(
+                self.inform2(format_args!(
                     "State {} is already available in {:#}",
                     state, location
                 ))?;
             } else {
-                self.inform(format_args!("Extending state {} to {:#}", state, location))?;
+                self.inform2(format_args!("Extending state {} to {:#}", state, location))?;
                 self.add_location_helper(&state, &location, wait).await?;
             }
         }
@@ -1396,7 +1400,7 @@ impl StateHub {
 
     async fn save_config(&self, set_default_profile: bool) -> anyhow::Result<()> {
         self.config.save(set_default_profile).and_then(|path| {
-            self.inform(format_args!("Saving config to {}", path.display()))
+            self.inform2(format_args!("Saving config to {}", path.display()))
                 .context("Inform")
         })
     }
@@ -1406,7 +1410,7 @@ impl StateHub {
             self.check_for_update_helper()
                 .await
                 .and_then(|(current, latest)| {
-                    self.inform(format_args!(
+                    self.inform2(format_args!(
                         "\nNewer version '{}' is available (you have '{}')\n",
                         latest, current
                     ))
@@ -1448,7 +1452,11 @@ impl StateHub {
         }
     }
 
-    fn inform(&self, text: impl fmt::Display) -> io::Result<()> {
+    fn inform(&self, text: impl fmt::Display) {
+        self.inform2(text).ok();
+    }
+
+    fn inform2(&self, text: impl fmt::Display) -> io::Result<()> {
         let text = format!("{}", self.style.apply_to(text));
         // let text = text.to_string();
         if !text.is_empty() {
