@@ -157,14 +157,18 @@ impl StateHub {
             && unowned_states
             && self.confirm_with_default("Claim ownership of unowned states", true);
 
-        if let Ok(locations) = kubectl.collect_node_locations().await {
-            if locations.iter().any(|location| location.is_aws()) {
-                self.aws_credentials_helper(&aws).await?;
-            }
-            if locations.iter().any(|location| location.is_azure()) {
-                self.azure_credentials_helper(&azure).await?;
-            }
-        }
+        let locations = kubectl.collect_node_locations().await.unwrap_or_default();
+
+        let aws = if locations.iter().any(|location| location.is_aws()) {
+            self.aws_credentials_helper(aws)
+        } else {
+            aws
+        };
+        let azure = if locations.iter().any(|location| location.is_azure()) {
+            self.azure_credentials_helper(azure)
+        } else {
+            azure
+        };
 
         let register_cluster = RegisterCluster::new(
             helm,
@@ -218,9 +222,6 @@ impl StateHub {
 
         let helm = k8s::Helm::new(skip_helm);
 
-        self.aws_credentials_helper(&aws).await?;
-        self.azure_credentials_helper(&azure).await?;
-
         let register_cluster = RegisterCluster::new(
             helm,
             provider,
@@ -258,7 +259,7 @@ impl StateHub {
             .await
             .map(Quiet)?;
 
-        self.inform(format_args!(
+        self.inform2(format_args!(
             "Registering {:#} cluster {} in {}",
             provider,
             cluster.name,
@@ -336,12 +337,33 @@ impl StateHub {
         Ok(())
     }
 
-    async fn aws_credentials_helper(&self, aws: &AwsCredentials) -> anyhow::Result<()> {
-        aws.validate()
+    fn aws_credentials_helper(&self, aws: AwsCredentials) -> AwsCredentials {
+        if aws.missing() {
+            self.inform("AWS/EKS cluster detected and you didn't provide any AWS credentials");
+            self.inform(
+                "Please follow this link to create AWS credentials: https://statehub.io/creds/aws",
+            );
+            self.inform("When done please copy/paste credentials here");
+            let access_key_id = self.input("AWS_ACCESS_KEY_ID").unwrap_or_default();
+            let secret_access_key = self.input("AWS_SECRET_ACCESS_KEY").unwrap_or_default();
+            AwsCredentials::new(access_key_id, secret_access_key)
+        } else {
+            aws
+        }
     }
 
-    async fn azure_credentials_helper(&self, azure: &AzureCredentials) -> anyhow::Result<()> {
-        azure.validate()
+    fn azure_credentials_helper(&self, azure: AzureCredentials) -> AzureCredentials {
+        if azure.missing() {
+            self.inform("Azure/AKS cluster detected and you didn't provide any Azure credentials");
+            self.inform("Please follow this link to create Azure credentials: https://statehub.io/creds/azure");
+            self.inform("When done please copy/paste credentials here");
+            let tenant_id = self.input("AZURE_TENANT_ID").unwrap_or_default();
+            let client_id = self.input("AZURE_CLIENT_ID").unwrap_or_default();
+            let client_secret = self.input("AZURE_CLIENT_SECRET").unwrap_or_default();
+            AzureCredentials::new(tenant_id, client_id, client_secret)
+        } else {
+            azure
+        }
     }
 
     pub(super) async fn add_location_helper(
@@ -508,7 +530,7 @@ or run following commands before running 'statehub register-cluster`
                     location
                 );
             } else {
-                self.inform(format_args!(
+                self.inform2(format_args!(
                     "Extending state {} to {}",
                     state.name, location
                 ))?;
@@ -709,7 +731,7 @@ or run following commands before running 'statehub register-cluster`
 
     pub(super) async fn update_helper(&self, version: semver::Version) -> anyhow::Result<()> {
         let version = version.to_string();
-        self.inform(format_args!("Downloading version {}", version))?;
+        self.inform2(format_args!("Downloading version {}", version))?;
         let file = self
             .get_package("statehub", &version)
             .await
